@@ -1,11 +1,8 @@
 """Module to store the common business model of all entities."""
 
-from typing import Union
+from typing import Any
 
-from pydantic import BaseModel  # noqa: E0611
-
-# E0611: No name 'BaseModel' in module 'pydantic'
-# https://github.com/samuelcolvin/pydantic/issues/1961
+from pydantic import BaseModel, PrivateAttr
 
 
 class Entity(BaseModel):
@@ -13,9 +10,17 @@ class Entity(BaseModel):
 
     Unlike value objects, they have *identity equality*. We can change their values, and
     they are still recognizably the same thing.
+
+    An entity with a negative id means that the id needs to be set by the repository.
     """
 
-    id_: Union[int, str]
+    id_: int = -1
+    _model_name: str = PrivateAttr()
+
+    def __init__(self, **data: Any) -> None:
+        """Set the _model_name attribute."""
+        super().__init__(**data)
+        self._model_name = self.__class__.__name__
 
     def __lt__(self, other: "Entity") -> bool:
         """Assert if an object is smaller than us.
@@ -26,9 +31,7 @@ class Entity(BaseModel):
         Raises:
             TypeError: If the id type of the objects is not compatible.
         """
-        if not isinstance(other.id_, type(self.id_)):
-            raise TypeError(f"{self} and {other} have incompatible ID types")
-        return self.id_ < other.id_  # type: ignore
+        return self.id_ < other.id_
 
     def __gt__(self, other: "Entity") -> bool:
         """Assert if an object is greater than us.
@@ -39,9 +42,7 @@ class Entity(BaseModel):
         Raises:
             TypeError: If the id type of the objects is not compatible.
         """
-        if not isinstance(other.id_, type(self.id_)):
-            raise TypeError(f"{self} and {other} have incompatible ID types")
-        return self.id_ > other.id_  # type: ignore
+        return self.id_ > other.id_
 
     def __hash__(self) -> int:
         """Create an unique hash of the class object."""
